@@ -11,7 +11,7 @@ package wildcard_test
 import (
 	"testing"
 
-	wildcard "github.com/IGLOU-EU/go-wildcard"
+	"github.com/IGLOU-EU/go-wildcard/v2"
 )
 
 // TestMatch - Tests validate the logic of wild card matching.
@@ -90,3 +90,11 @@ func TestMatch(t *testing.T) {
 		}
 	}
 }
+
+func FuzzMatch(f *testing.F) {
+	f.Fuzz(func(t *testing.T, s string) {
+		if !wildcard.Match(s, s) {
+			t.Fatalf("%s does not match %s", s, s)
+		}
+	})
+}
